# geotils library

Added CI/CD to publish to PyPI using this [PyPY documentation](https://packaging.python.org/en/latest/guides/publishing-package-distribution-releases-using-github-actions-ci-cd-workflows/)  